@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 """
@@ -24,10 +23,16 @@ logger = logging.getLogger(__name__)
 
 USER_CONFIG_PATH = os.path.expanduser('~/.cookiecutterrc')
 
+BUILTIN_ABBREVIATIONS = {
+    'gh': 'https://github.com/{0}.git',
+    'bb': 'https://bitbucket.org/{0}',
+}
+
 DEFAULT_CONFIG = {
     'cookiecutters_dir': os.path.expanduser('~/.cookiecutters/'),
     'replay_dir': os.path.expanduser('~/.cookiecutter_replay/'),
-    'default_context': {}
+    'default_context': {},
+    'abbreviations': BUILTIN_ABBREVIATIONS,
 }
 
 
@@ -68,13 +73,24 @@ def get_config(config_path):
     return config_dict
 
 
-def get_user_config(config_file=USER_CONFIG_PATH):
-    """Retrieve the config from a file or return the defaults if None is
-    passed. If an environment variable `COOKIECUTTER_CONFIG` is set up, try
-    to load its value. Otherwise fall back to a default file or config.
+def get_user_config(config_file=None, default_config=False):
+    """Return the user config as a dict.
+
+    If ``default_config`` is True, ignore ``config_file and return default
+    values for the config parameters.
+
+    If a path to a ``config_file`` is given, that is different from the default
+    location, load the user config from that.
+
+    Otherwise look up the config file path in the ``COOKIECUTTER_CONFIG``
+    environment variable. If set, load the config from this path. This will
+    raise an error if the specified path is not valid.
+
+    If the environment variable is not set, try the default config file path
+    before falling back to the default config values.
     """
     # Do NOT load a config. Return defaults instead.
-    if config_file is None:
+    if default_config:
         return copy.copy(DEFAULT_CONFIG)
 
     # Load the given config file
